LargeDataExplorer-package: LargeDataExplorer: Powerful package to clean and re-format...

Description Author(s) See Also

Description

This package can identify the irrelevant variables for machine learning and exclude them, while keeping and tranforming the useful ones. It also can explore a dataset, categorizing its variables as numeric, categorical (text), categorical (number), boolean, date, primary keys, keys, NA-variable, Univalue, plain text and variables with repeated information. It will also calculate the basic statistics for each variable.

Author(s)

Maintainer: Daniel Nieto nieto.daniel221@gmail.com (ORCID)

See Also

Useful links:


nietodaniel/LargeDataExplorer documentation built on Sept. 20, 2020, 7:57 p.m.