secop1.full: State contracts dataset. Each row is a state procurement...

Description Usage Format

Description

Modified and shortened datased based on "SECOP I - 2020: Data set of the processes published in SECOP I during the year 2020", a dataset published under the Colombian government's project "Colombia Compra Eficiente" which seeks to reduce corruption by publicly publishing the state procurement processes. https://www.colombiacompra.gov.co/ The original dataset was published under the Open Contracting Data Standard License (ODCS), which means it is open for any use. The authors of this package have no role in the Colombian government

Usage

1

Format

An object of class spec_tbl_df (inherits from tbl_df, tbl, data.frame) with 7349 rows and 72 columns.


nietodaniel/LargeDataExplorer documentation built on Sept. 20, 2020, 7:57 p.m.