Description Author(s) See Also
This package can identify the irrelevant variables for machine learning and exclude them, while keeping and tranforming the useful ones. It also can explore a dataset, categorizing its variables as numeric, categorical (text), categorical (number), boolean, date, primary keys, keys, NA-variable, Univalue, plain text and variables with repeated information. It will also calculate the basic statistics for each variable.
Maintainer: Daniel Nieto nieto.daniel221@gmail.com (ORCID)
Useful links:
Report bugs at https://github.com/nietodaniel/LargeDataExplorer/issues
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.