Modified and shortened datased based on "Multas y Sanciones SECOP I: Dataset of the fines and sanctions generated in the SECOP I platform", a dataset published under the Colombian government's project "Colombia Compra Eficiente" which seeks to reduce corruption by publicly publishing the state procurement processes. https://www.colombiacompra.gov.co/ The original dataset was published under the Open Contracting Data Standard License (ODCS), which means it is open for any use. The authors of this package have no role in the Colombian government
1 |
An object of class spec_tbl_df (inherits from tbl_df, tbl, data.frame) with 1442 rows and 12 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.